// Programmed using the knockoff Pro Micro boards - use Arduino/Genuino Micro as board type.
// Watch out - your board's name might change and you'll have to select it again in Tools/Port after
// your program it the first time.

// Anything on a line after "//" is commented out - the microcontoller will ignore it!

// This sketch is just to check your sensors + switches are working
// This is good practice to make sure all your hardware is working the way you are expecting it to

// Set up synonyms to make writing the code easier and more logical
#define Button 10    // Right button pin is connected to Pin Number 10
#define LED 9        // LED use for signalling the state of the board is connected to Pin Number 10
#define Pressure A0  // Gauge Pressure sensor is connected to analog input pin A0

// The setup loop runs once when the board powers on
void setup() {
  // Setup the inputs and outputs:
  pinMode(Button, INPUT_PULLUP); // we use a "pull-up" resistor to make our circuit simpler
  pinMode(LED, OUTPUT);         // Define this pin as outputting a signal to our LED
  pinMode(Pressure, INPUT);     // Define this pin as an input - it has Analog Read capability!
}

// the main loop runs over and over...
void loop() {
  int Pval = analogRead(Pressure); // Read the A0 Pin attached to the Pressure Sensor
  Serial.println(Pval);            // Print this to the Serial Monitor so we can see what
                                   // Pressure sensor voltage reading is
  // To use the Serial Monitor, go to the top menu "Tools/Serial Monitor"
  // Make sure you have your board showing up and selected under "Tools/Port"                                   
  
  int Bval = digitalRead(Button); // Read the state of the pin attached to our momentary switch (button)
  // We're using a "pull-up", so when the button is not pressed it will read "1"
  // When it is pressed it will read "0"
  
  digitalWrite(LED, Bval);  // Write the state of the button to the LED pin
  // When Bval is "1", the LED will be on full intensity - this is when you don't press the button
  // When Bval is "0", the LED will be off - this is when you do press the button

  delay(100); // Stop executing code for 100ms so we don't send a crazy amount of messages
  // There is a better way to do this, but for debugging, this is fine.
}

